@@ -7,18 +7,14 @@ from typing import Any, Dict, List, Optional, Pattern, Tuple, Union
 
 import rich_click as click
 
+from robotidy import skip
 from robotidy.app import Robotidy
+from robotidy.config import Config, FormattingConfig
 from robotidy.decorators import catch_exceptions
 from robotidy.files import DEFAULT_EXCLUDES, find_and_read_config, read_pyproject_config
 from robotidy.rich_console import console
 from robotidy.transformers import load_transformers
-from robotidy.utils import (
-    ROBOT_VERSION,
-    GlobalFormattingConfig,
-    RecommendationFinder,
-    TargetVersion,
-    split_args_from_name_or_path,
-)
+from robotidy.utils import ROBOT_VERSION, RecommendationFinder, TargetVersion, split_args_from_name_or_path
 from robotidy.version import __version__
 
 click.rich_click.USE_RICH_MARKUP = True
@@ -52,6 +48,7 @@ click.rich_click.OPTION_GROUPS = {
             "options": [
                 "--spacecount",
                 "--indent",
+                "--continuation-indent",
                 "--line-length",
                 "--lineseparator",
                 "--separator",
@@ -60,6 +57,7 @@ click.rich_click.OPTION_GROUPS = {
             ],
         },
         {"name": "File exclusion", "options": ["--exclude", "--extend-exclude", "--skip-gitignore"]},
+        skip.option_group,
         {
             "name": "Other",
             "options": ["--target-version", "--verbose", "--color", "--output", "--version", "--help"],
@@ -229,9 +227,8 @@ def print_transformers_list(target_version: int):
         "A regular expression that matches files and directories that should be"
         " excluded on recursive searches. An empty value means no paths are excluded."
         " Use forward slashes for directories on all platforms."
-        f" \[default: '{DEFAULT_EXCLUDES}']"
     ),
-    show_default=False,
+    show_default=f"{DEFAULT_EXCLUDES}",
 )
 @click.option(
     "--extend-exclude",
@@ -299,7 +296,15 @@ def print_transformers_list(target_version: int):
     "--indent",
     type=click.types.INT,
     default=None,
-    help="The number of spaces to be used as indentation [default: same as --spacecount value]",
+    help="The number of spaces to be used as indentation",
+    show_default="same as --spacecount value",
+)
+@click.option(
+    "--continuation-indent",
+    type=click.types.INT,
+    default=None,
+    help="The number of spaces to be used as separator after ... (line continuation) token",
+    show_default="same as --spacecount value]",
 )
 @click.option(
     "-ls",
@@ -333,7 +338,6 @@ def print_transformers_list(target_version: int):
     type=int,
     help="Limit robotidy only to selected area. If **--endline** is not provided, format text only at **--startline**. "
     "Line numbers start from 1.",
-    show_default=True,
 )
 @click.option(
     "-el",
@@ -341,7 +345,6 @@ def print_transformers_list(target_version: int):
     default=None,
     type=int,
     help="Limit robotidy only to selected area. Line numbers start from 1.",
-    show_default=True,
 )
 @click.option(
     "--line-length",
@@ -383,8 +386,21 @@ def print_transformers_list(target_version: int):
     "-t",
     type=click.Choice([v.name.lower() for v in TargetVersion], case_sensitive=False),
     callback=validate_target_version,
-    help="Only enable transformers supported in set target version. \[default: installed Robot Framework version]",
+    help="Only enable transformers supported in set target version",
+    show_default="installed Robot Framework version",
 )
+@skip.documentation_option
+@skip.return_values_option
+@skip.keyword_call_option
+@skip.keyword_call_pattern_option
+@skip.settings_option
+@skip.arguments_option
+@skip.setup_option
+@skip.teardown_option
+@skip.timeout_option
+@skip.template_option
+@skip.return_option
+@skip.tags_option
 @click.version_option(version=__version__, prog_name="robotidy")
 @click.pass_context
 @catch_exceptions
@@ -402,6 +418,7 @@ def cli(
     check: bool,
     spacecount: int,
     indent: Optional[int],
+    continuation_indent: Optional[int],
     lineseparator: str,
     verbose: bool,
     config: Optional[str],
@@ -414,6 +431,18 @@ def cli(
     output: Optional[Path],
     force_order: bool,
     target_version: int,
+    skip_documentation: bool,
+    skip_return_values: bool,
+    skip_keyword_call: List[str],
+    skip_keyword_call_pattern: List[str],
+    skip_settings: bool,
+    skip_arguments: bool,
+    skip_setup: bool,
+    skip_teardown: bool,
+    skip_timeout: bool,
+    skip_template: bool,
+    skip_return: bool,
+    skip_tags: bool,
 ):
     """
     Robotidy is a tool for formatting Robot Framework source code.
@@ -442,22 +471,37 @@ def cli(
         # None is default, with check not set -> overwrite, with check set -> overwrite only when overwrite flag is set
         overwrite = not check
 
-    if indent is None:
-        indent = spacecount
-
     if color:
         color = "NO_COLOR" not in os.environ
 
-    formatting_config = GlobalFormattingConfig(
+    skip_config = skip.SkipConfig(
+        documentation=skip_documentation,
+        return_values=skip_return_values,
+        keyword_call=skip_keyword_call,
+        keyword_call_pattern=skip_keyword_call_pattern,
+        settings=skip_settings,
+        arguments=skip_arguments,
+        setup=skip_setup,
+        teardown=skip_teardown,
+        template=skip_template,
+        timeout=skip_timeout,
+        return_statement=skip_return,
+        tags=skip_tags,
+    )
+
+    formatting = FormattingConfig(
         space_count=spacecount,
         indent=indent,
+        continuation_indent=continuation_indent,
         line_sep=lineseparator,
         start_line=startline,
         separator=separator,
         end_line=endline,
         line_length=line_length,
     )
-    tidy = Robotidy(
+    config = Config(
+        formatting=formatting,
+        skip=skip_config,
         transformers=transform,
         transformers_config=configure,
         src=src,
@@ -466,7 +510,6 @@ def cli(
         skip_gitignore=skip_gitignore,
         overwrite=overwrite,
         show_diff=diff,
-        formatting_config=formatting_config,
         verbose=verbose,
         check=check,
         output=output,
@@ -474,5 +517,6 @@ def cli(
         target_version=target_version,
         color=color,
     )
+    tidy = Robotidy(config=config)
     status = tidy.transform_files()
     sys.exit(status)
