@@ -1,15 +1,17 @@
-from robot.api.parsing import KeywordCall, ModelTransformer, Token
+from robot.api.parsing import KeywordCall, Token
 
 try:
-    from robot.api.parsing import InlineIfHeader
+    from robot.api.parsing import InlineIfHeader, ReturnStatement
 except ImportError:
     InlineIfHeader = None
+    ReturnStatement = None
 
-from robotidy.disablers import skip_if_disabled, skip_section_if_disabled
+from robotidy.disablers import Skip, skip_if_disabled, skip_section_if_disabled
 from robotidy.exceptions import InvalidParameterValueError
+from robotidy.transformers import Transformer
 
 
-class NormalizeSeparators(ModelTransformer):
+class NormalizeSeparators(Transformer):
     """
     Normalize separators and indents.
 
@@ -24,10 +26,12 @@ class NormalizeSeparators(ModelTransformer):
     Supports global formatting params: ``--startline`` and ``--endline``.
     """
 
-    def __init__(self, sections: str = None, skip_documentation: bool = False):
+    HANDLES_SKIP = frozenset({"skip_documentation", "skip_keyword_call", "skip_keyword_call_pattern"})
+
+    def __init__(self, sections: str = None, skip: Skip = None):
+        super().__init__(skip=skip)
         self.indent = 0
         self.sections = self.parse_sections(sections)
-        self.skip_documentation = skip_documentation
         self.is_inline = False
 
     def parse_sections(self, sections):
@@ -123,13 +127,20 @@ class NormalizeSeparators(ModelTransformer):
         return node
 
     def visit_Documentation(self, doc):  # noqa
-        if self.skip_documentation:
+        if self.skip.documentation:
             has_pipes = doc.tokens[0].value.startswith("|")
             return self._handle_spaces(doc, has_pipes, only_indent=True)
         return self.visit_Statement(doc)
 
+    def visit_KeywordCall(self, keyword):  # noqa
+        if self.skip.keyword_call(keyword):
+            return keyword
+        return self.visit_Statement(keyword)
+
     def is_keyword_inside_inline_if(self, node):
-        return self.is_inline and isinstance(node, KeywordCall)
+        return self.is_inline and (
+            isinstance(node, KeywordCall) or ReturnStatement and isinstance(node, ReturnStatement)
+        )
 
     @skip_if_disabled
     def visit_Statement(self, statement):  # noqa
@@ -138,6 +149,7 @@ class NormalizeSeparators(ModelTransformer):
 
     def _handle_spaces(self, statement, has_pipes, only_indent=False):
         new_tokens = []
+        prev_token = None
         for line in statement.lines:
             prev_sep = False
             for index, token in enumerate(line):
@@ -148,9 +160,13 @@ class NormalizeSeparators(ModelTransformer):
                     if index == 0 and not self.is_keyword_inside_inline_if(statement):
                         token.value = self.formatting_config.indent * self.indent
                     elif not only_indent:
-                        token.value = self.formatting_config.separator
+                        if prev_token and prev_token.type == Token.CONTINUATION:
+                            token.value = self.formatting_config.continuation_indent
+                        else:
+                            token.value = self.formatting_config.separator
                 else:
                     prev_sep = False
+                    prev_token = token
                 if has_pipes and index == len(line) - 2:
                     token.value = token.value.rstrip()
                 new_tokens.append(token)
